# Project_2-v2
Updated project 


Description

The goal of this project was to make the code of my previous project better. The previous project has three main purposes. It scrapes data from the web regarding weather and stock information.
This project makes much more use of functions and classes. 

Goals of Project

Functions and Classes

Common functions is a module that contains functions that are used throughout. 
main_classes uses class which get referred to throughout. These include classes where all the paramaters and xpaths can be changed and located. 
There are additional classes for non duplicating lists and lists of dictionaries to match values together in a four dimensional sense. 

How to use. 

The defaulter scrapers can be actiated by simply typing scrape_wikipedia(), scrape_urls() and scrape_weather(). The later two rely on specific inputs. Default values are used but they can be changed by altering the test functions above the functions. 
Inside each scraping class page, you can access methods which do more specific things. These are for doing operations like scraping data for a specific day.

What I learned in this project. 

A lot of python tricks were only found in the late stages of development and I wish I integrated them earlier. I should have also started coding the functions with more specific actions first rather than the most general ones. 
I also learned about the importance of testing. In the future I should use a more rigid testing style relying on hypotheseis testing. 
I should also match my code with the standard code layout and use of docstrings. 